<?php

namespace Drupal\extra_field_views\Plugin\ExtraField\Display;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\extra_field\Annotation\ExtraFieldDisplay;
use Drupal\extra_field_plus\Plugin\ExtraFieldPlusDisplayBase;

/**
 * Provides an Extra Field Display plugin to embed views.
 *
 * @ExtraFieldDisplay(
 *   id = "views",
 *   label = @Translation("View"),
 *   description = @Translation("Displays a view with a given display"),
 *   bundles = { "*.*" },
 * )
 */
class ViewsExtraFieldDisplay extends ExtraFieldPlusDisplayBase {

  /**
   * Provides default settings for the extra field.
   *
   * @return array
   *   An associative array of default settings, including:
   *   - view: The machine name of the view.
   *   - display: The display ID of the view.
   */
  protected static function defaultExtraFieldSettings(): array {
    return [
      'view' => NULL,
      'display' => NULL,
    ];
  }

  /**
   * Builds the settings form for the extra field.
   *
   * @return array
   *   A form array for the extra field settings.
   */
  protected static function extraFieldSettingsForm(): array {
    $form = parent::extraFieldSettingsForm();

    $form['view'] = [
      '#type' => 'textfield',
      '#title' => t('View'),
    ];

    $form['display'] = [
      '#type' => 'textfield',
      '#title' => t('Display'),
    ];

    return $form;
  }

  /**
   * Renders the extra field.
   *
   * @param \Drupal\Core\Entity\ContentEntityInterface $entity
   *   The entity to which the extra field is attached.
   *
   * @return array
   *   A render array for the view.
   */
  public function view(ContentEntityInterface $entity): array {
    $settings = $this->getEntityExtraFieldSettings();

    // Ensure view and display are set and valid.
    if (!empty($settings['view']) && !empty($settings['display'])) {
      $view = views_embed_view($settings['view'], $settings['display']);
      if ($view !== NULL) {
        return $view;
      }
    }

    // If the view or display is invalid or missing, return an empty array.
    return [
      '#markup' => $this->t('View could not be displayed.'),
    ];
  }

}
